//------------------------------------------------------------//
//                                                            //
//   PROJECT:  costume rent                                   //
//                                                            //
//   FILE:     main.cpp                                       //
//   AUTHOR:   Irma Dobrovolskyte                             //
//                                                            //
//------------------------------------------------------------//
#include <iostream>
#include <list>
#include "costume.h"

using namespace std;

typedef std::list<Costume*>  CostumeList;
typedef std::list<Lease*>    LeaseList;

//------------------------------------------------------------
Costume* selectCostume     (CostumeList& costumeList);

void printCostumeList   (CostumeList& costumeList);
void addNewCostume      (CostumeList& costumeList);
void sellCostume        (CostumeList& col, LeaseList& lel);
void removeLease        (CostumeList& col, LeaseList& lel);
void showCostumeDetails (CostumeList& costumeList);
void showProfit         (LeaseList& leaseList);
          
//============================================================//
//                                                            //
//    main ()                                                 //
//                                                            //
//============================================================//
int main ()
{
   cout << "//---------------------------------------------//" << endl
        << "//                                             //" << endl
        << "//   Matematikos ir informatikos fakultetas    //" << endl          
        << "//       Informatika 2 kursas 5 grupe          //" << endl
        << "//                                             //" << endl
        << "//       2 uzduotis (variantas Nr. 30)         //" << endl
        << "//          KOSTIUMU NUOMOS PUNKTAS            //" << endl  
        << "//                                             //" << endl
        << "//         Autore: Irma Dobrovolskyte          //" << endl
        << "//---------------------------------------------//" << endl;
   
   CostumeList   costumeList;
   LeaseList     leaseList;
   for (;;)
   {
      cout << endl
           << "Nuomojami kostiumai:"      << endl
           << "  1 - sarasas"             << endl
           << "  2 - sukurti"             << endl
           << "  3 - isnuomoti"           << endl
           << "  4 - kostiumo detales"    << endl
           << "  5 - laikotarpio pelnas"  << endl
           <<  endl
           << "  0 - baigti darba"        << endl;
       string key;    
       cin >> key;
            if (key == "0") return 0;
       else if (key == "1") printCostumeList(costumeList);
       else if (key == "2") addNewCostume(costumeList);
       else if (key == "3") sellCostume(costumeList, leaseList);
       else if (key == "4") showCostumeDetails(costumeList);
       else if (key == "5") showProfit(leaseList);
       else cout << endl << "Neteisinga komanda..." << endl;   
   }
}
//------------------------------------------------------------
Costume* selectCostume (CostumeList& costumeList)
{
   for (;;)
   {
      string title;
      printCostumeList(costumeList);
      cout << "Pasirinkite kostiuma ('@'-baigti): ";
      cin >> title;
      if (title == "@")
          return 0;
      cout << endl;
      CostumeList::iterator iter = costumeList.begin();
      for (;  iter != costumeList.end();  iter++)
         if (title == (*iter)->getTitle())
             return *iter;
   }
   return 0; // unreacheable
}
//------------------------------------------------------------
void printCostumeList (CostumeList& costumeList)
{
   cout << "== KOSTIUMU SARASAS  (is viso " << costumeList.size() << ")==" << endl;
   CostumeList::iterator iter = costumeList.begin();
   for (;  iter != costumeList.end();  iter++)
      (*iter)->print();
}
//------------------------------------------------------------
void addNewCostume (CostumeList& costumeList)
{
   string title;
   double price;
   cout << "== Naujas kostiumas ==" << endl;
   cout << " PAVADINIMAS:           ";  cin >> title;
   cout << " 1 dienos nuomos kaina: ";  cin >> price;
   costumeList.push_back(new Costume(title, price));     
}
//------------------------------------------------------------
void sellCostume (CostumeList& costumeList, LeaseList& leaseList)
{
   cout << "== Kostiumo nuoma ==" << endl;
   Costume* costume = selectCostume(costumeList);
   if (costume == 0) return;
   string date;
   string name;
   string surname;
   int    day;
   int    itemCount;
   costume->print();
   cout << "  Nuomos data (yyyy.mm.dd): "; cin >> date;
   cout << "  Kliento vardas:           "; cin >> name;
   cout << "  Kliento pavarde:          "; cin >> surname;
   cout << "  Nuomos dienu skaicius:    "; cin >> day;
   cout << "  Kostiumu kiekis:          "; cin >> itemCount;
   Lease* lease =
      new Lease(costume, date, name, surname, day, itemCount);
   costume->addLease(lease);
   leaseList.push_back(lease);
}
//------------------------------------------------------------
void removeLease (CostumeList& costumeList, LeaseList& leaseList)
{
   cout << "== Kostiumo nuoma ==" << endl;
   Costume* costume = selectCostume(costumeList);
   if (costume == 0) return;
   string date;
   string name;
   string surname;
   int    day;
   int    itemCount;
   costume->print();
   cout << "  Nuomos data (yyyy.mm.dd): "; cin >> date;
   cout << "  Kliento vardas:           "; cin >> name;
   cout << "  Kliento pavarde:          "; cin >> surname;
   cout << "  Nuomos dienu skaicius:    "; cin >> day;
   cout << "  Kostiumu kiekis:          "; cin >> itemCount;
   Lease* lease =
      new Lease(costume, date, name, surname, day, itemCount);
   costume->addLease(lease);
   leaseList.push_back(lease);
}
//------------------------------------------------------------
void showCostumeDetails(CostumeList& costumeList)
{
   cout << "== Kostiumo nuomos detales ==" << endl;
   Costume* costume = selectCostume(costumeList);
   if (costume == 0) return;
   cout << " Kostiumu nuoma: ";
   costume->print();
   for (int i = 0; i < costume->getLeaseCount(); i++)
      costume->getLease(i)->print();
}
//------------------------------------------------------------
void showProfit(LeaseList& leaseList)
{
   string dateFrom;
   string dateTo;
   cout << "== Laikotarpio nuomos pelnas ==" << endl;
   cout << "   nuo kada (yyyy.mm.dd): "; cin >> dateFrom;
   cout << "   iki kada (yyyy.mm.dd): "; cin >> dateTo;
   double totalProfit = 0;
   LeaseList::iterator iter = leaseList.begin();
   for (;  iter != leaseList.end();  iter++)
      if (dateFrom <= (*iter)->getDate()  &&
          (*iter)->getDate() <= dateTo)
      {
         (*iter)->print();
         totalProfit += (*iter)->getProfit();
      }
   cout << " laikotarpio pelnas: " << totalProfit << endl;
}
//============================================================//
